export interface IOptions {
    size?: number;
    offline?: boolean;
}
export interface IOutput {
    encoded: string;
    width: number;
    height: number;
}
/**
 * Generate a Blurhash string from a given image URL or local path.
 *
 * @param {string} source - The image URL or local path to the image file.
 * @param {IOptions} [options] - The optional configuration options.
 * @param {number} [options.size=32] - The desired size of the image for encoding the Blurhash.
 * @param {boolean} [options.offline=false] - Set to `true` if the image source is a local path, `false` if it's a URL.
 * @returns {Promise<IOutput>} The Promise that resolves to the encoded Blurhash string, along with the image width and height.
 * @default size 32
 * @default offline false
 * @example
 * ```js
 * import { blurhashFromURL } from "blurhash-from-url";
 *
 * const output = await blurhashFromURL("https://i.imgur.com/NhfEdg2.png", {
 *    size: 32,
 * });
 *
 * console.log(output);
 * ```
 */
export declare const blurhashFromURL: (source: string, options?: IOptions) => Promise<IOutput>;
